<?php
if (!defined('ABSPATH')) {
  exit; // Exit if accessed directly.
}
/*
 * @package eventpress builder
 * since 1.0.0
 * 
*/


// image size
add_image_size('swp_eventpress_370x270', 370, 270, true);
add_image_size('swp_eventpress_370x500', 370, 500, false);
add_image_size('swp_eventpress_770x460', 770, 460, false);



if (!function_exists('swp_eventpress_post_query')) {
  function swp_eventpress_post_query($post_type)
  {
    $post_list = get_posts(array(
      'post_type' => $post_type,
      'showposts' => -1,
    ));
    $posts = array();

    if (!empty($post_list) && !is_wp_error($post_list)) {
      foreach ($post_list as $post) {
        $options[$post->ID] = $post->post_title;
      }
      return $options;
    }
  }
}

//select category
function swp_eventpress_post_category($terms = 'event_cat')
{

  $terms = get_terms(array(
    'taxonomy'       => $terms,
    'hide_empty'     => false,
    'posts_per_page' => -1,
  ));

  $category_list = [];
  foreach ($terms as $post) {
    $category_list[$post->term_id] = [$post->name];
  }

  return $category_list;
}

//select post 
function swp_eventpress_select_post()
{

  $args       = array('post_type' => 'event', 'posts_per_page' => -1);
  $post_lists = [];

  if ($postlists = get_posts($args)) {
    foreach ($postlists as $postlist) {
      (int) $post_lists[$postlist->ID] = $postlist->post_title;
    }
  } else {
    (int) $post_lists['0'] = esc_html__('No Post Found', 'swp-eventpress');
  }

  return $post_lists;
}

function swp_eventpress_get_cat_name($cat_id)
{
  $cat_id   = (int) $cat_id;
  $category = get_term($cat_id, 'event_cat');

  if (!$category || is_wp_error($category)) {
    return '';
  }

  return $category->name;
}

// caategory slug
function swp_eventpress_get_cat_slug($cat_id)
{
  $cat_id   = (int) $cat_id;
  $category = get_term($cat_id, 'event_cat');

  if (!$category || is_wp_error($category)) {
    return '';
  }

  return $category->slug;
}


add_filter('template_include',  'swp_eventpress_template', 99);

function swp_eventpress_template($template)
{
  global $post;


  if ('event' === $post->post_type && locate_template(array('single-event.php')) !== $template) {
    /*
            * This is a 'eventpress' post
            * AND a 'single eventpress template' is not found on
            * theme or child theme directories, so load it
            * from our plugin directory.
            */
    return SWP_EVENTPRESS_ROOT_PATH . '/template/single-event.php';
  }

  return $template;
}

// Add a filter to 'template_include' hook
add_filter('template_include', 'swp_eventpress_archive_template', 99);
function swp_eventpress_archive_template($template)
{

  // If the current url is an archive of any kind
  if (is_tax('event_cat')) {
    // Set this to the template file inside your plugin folder
    $template = SWP_EVENTPRESS_ROOT_PATH . '/template/archive-eventpress.php';
  }
  // Always return, even if we didn't change anything
  return $template;
}



if (!function_exists('swp_eventpress_slug')) {
  function swp_eventpress_slug()
  {
    global $post;

    $swp_eventpress_link = get_permalink($post->ID);

    if (empty($swp_eventpress_link)) {
      return FALSE;
    } else {
      $swp_eventpress_link = str_replace(home_url('/'), '', $swp_eventpress_link);
      return $swp_eventpress_link;
    }
  }
}

add_filter('wpcf7_autop_or_not', '__return_false');

if (!function_exists('swp_eventpress_get_template')) :
  function swp_eventpress_get_template($template_name = null)
  {
    $template_path = apply_filters('swp-eventpress-elementor/template-path', 'elementor-templates/');
    $template = locate_template($template_path . $template_name);
    if (!$template) {
      $template = SWP_EVENTPRESS_ELEMENTOR  . '/templates/' . $template_name;
    }
    if (file_exists($template)) {
      return $template;
    } else {
      return false;
    }
  }
endif;



add_action('init', 'swp_eventpress_elementor_cpt_support');
function swp_eventpress_elementor_cpt_support()
{

  //if exists, assign to $cpt_support var
  $cpt_support = get_option('elementor_cpt_support');

  //check if option DOESN'T exist in db
  if (!$cpt_support) {
    $cpt_support = ['page', 'post', 'event']; //create array of our default supported post types
    update_option('elementor_cpt_support', $cpt_support); //write it to the database
  }

  //if it DOES exist, but footer is NOT defined
  else if (!in_array('event', $cpt_support)) {
    $cpt_support[] = 'event'; //append to array
    update_option('elementor_cpt_support', $cpt_support); //update database
  }
}

add_action('save_post', 'swp_eventpress_event_meta');
function swp_eventpress_event_meta($post_id)
{


  $post_type = get_post_type($post_id);

  if ($post_type == 'event') {

    if (isset($_POST['swp_eventpress_meta']['event_date'])) {
      $eventdate = strtotime($_POST['swp_eventpress_meta']['event_date']);

      update_post_meta($post_id, 'swp_event_date', $eventdate);
    }
  } //endif


} //end swp_eventpress_event_meta

function swp_event_custom_flush_rules()
{
  // Flush rewrite rules
  if (get_option('swp_event_when_active') == 1) :
    flush_rewrite_rules();
    delete_option('swp_event_when_active');
  endif;
}
add_action('init', 'swp_event_custom_flush_rules');
